@@ -8,14 +8,15 @@ import traceback
 from typing import Awaitable, List, Dict, Callable, Optional, Set, Tuple
 from nonebot import get_driver
 from nonebot import on_command, on_message, on_notice
-from nonebot.log import logger
+from .logger import logger
 from nonebot.params import CommandArg, Matcher, Event
 from nonebot.adapters.onebot.v11 import Bot, Message, MessageEvent, PrivateMessageEvent, GroupMessageEvent, MessageSegment, GroupIncreaseNoticeEvent
 
 from .config import *
 from .utils import *
-from .chat import Chat, global_chat_dict
+from .chat import Chat
 from .persistent_data_manager import PersistentDataManager
+from .chat_manager import ChatManager
 from .Extension import Extension, global_extensions
 from .openai_func import TextGenerator
 from .command_func import CommandManager, cmd
@@ -53,7 +54,8 @@ async def handler(matcher_:Matcher, event: MessageEvent, bot:Bot) -> None:
             return
         
     if len(msg_sent_set) > 10:
-        logger.warning(f"累积的待处理的自己发送消息数量为 {len(msg_sent_set)}, 请检查逻辑是否有错误")
+        if config.DEBUG_LEVEL > 0: logger.warning(f"累积的待处理的自己发送消息数量为 {len(msg_sent_set)}, 请检查逻辑是否有错误")
+        msg_sent_set.clear()
     
     # 处理消息前先检查权限
     (permit_success, _) = await permission_check_func(matcher=matcher_, event=event, bot=bot, cmd=None, type='message')
@@ -62,7 +64,7 @@ async def handler(matcher_:Matcher, event: MessageEvent, bot:Bot) -> None:
     
     # 判断用户账号是否被屏蔽
     if event.get_user_id() in config.FORBIDDEN_USERS:
-        logger.info(f"用户 {event.get_user_id()} 被屏蔽，拒绝处理消息")
+        if config.DEBUG_LEVEL > 0: logger.info(f"用户 {event.get_user_id()} 被屏蔽，拒绝处理消息")
         return
 
     sender_name = await get_user_name(event=event, bot=bot, user_id=event.user_id) or '未知'
@@ -83,7 +85,7 @@ async def handler(matcher_:Matcher, event: MessageEvent, bot:Bot) -> None:
 
     # 如果是忽略前缀 或者 消息为空，则跳过处理
     if event.get_plaintext().strip().startswith(config.IGNORE_PREFIX) or not event.get_plaintext():   
-        logger.info("忽略前缀或消息为空，跳过处理...")
+        if config.DEBUG_LEVEL > 1: logger.info("忽略前缀或消息为空，跳过处理...") # 纯图片消息也会被判定为空消息
         return
 
     # 判断群聊/私聊
@@ -94,7 +96,7 @@ async def handler(matcher_:Matcher, event: MessageEvent, bot:Bot) -> None:
         chat_key = 'private_' + event.get_user_id()
         chat_type = 'private'
     else:
-        logger.info("未知消息来源: " + event.get_session_id())
+        if config.DEBUG_LEVEL > 0: logger.info("未知消息来源: " + event.get_session_id())
         return
     
     chat_text, wake_up = await gen_chat_text(event=event, bot=bot)
@@ -174,18 +176,11 @@ async def _(matcher_:Matcher, event: MessageEvent, bot:Bot, arg: Message = Comma
     elif isinstance(event, PrivateMessageEvent):
         chat_key = 'private_' + event.get_user_id()
     else:
-        logger.info("未知消息来源: " + event.get_session_id())
+        if config.DEBUG_LEVEL > 0: logger.info("未知消息来源: " + event.get_session_id())
         return
 
-    # 判断是否已经存在对话
-    if chat_key in global_chat_dict:
-        if config.DEBUG_LEVEL > 0: logger.info(f"已存在对话 {chat_key} - 继续对话")
-    else:
-        if config.DEBUG_LEVEL > 0: logger.info("不存在对话 - 创建新对话")
-        # 创建新对话
-        global_chat_dict[chat_key] = Chat(chat_key)
-    chat:Chat = global_chat_dict[chat_key]
-    chat_presets_dict = PersistentDataManager.instance.get_presets(chat_key)
+    chat:Chat = ChatManager.instance.get_or_create_chat(chat_key=chat_key)
+    chat_presets_dict = chat.chat_data.preset_datas
 
     raw_cmd:str = arg.extract_plain_text()
     if config.DEBUG_LEVEL > 0: logger.info(f"接收到指令: {raw_cmd} | 来源: {chat_key}")
@@ -225,26 +220,20 @@ async def _(matcher_:Matcher, event: MessageEvent, bot:Bot, arg: Message = Comma
 
 
 """ ======== 消息响应方法 ======== """
-# 消息响应方法
 async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, matcher: Matcher, chat_type: str, chat_key: str, sender_name: str = None, wake_up: bool = False, loop_times=0, loop_data={}):
-    # 判断是否已经存在对话
-    if chat_key in global_chat_dict:
-        if config.DEBUG_LEVEL > 0: logger.info(f"已存在对话 {chat_key} - 继续对话")
-    else:
-        if config.DEBUG_LEVEL > 0: logger.info("不存在对话 - 创建新对话")
-        # 创建新对话
-        global_chat_dict[chat_key] = Chat(chat_key)
-    chat:Chat = global_chat_dict[chat_key]
+    """消息响应方法"""
+
+    chat:Chat = ChatManager.instance.get_or_create_chat(chat_key=chat_key)
 
     # 判断对话是否被禁用
     if not chat.is_enable:
-        logger.info("对话已被禁用，跳过处理...")
+        if config.DEBUG_LEVEL > 1: logger.info("对话已被禁用，跳过处理...")
         return
 
     # 检测是否包含违禁词
     for w in config.WORD_FOR_FORBIDDEN:
         if str(w).lower() in trigger_text.lower():
-            logger.info(f"检测到违禁词 {w}，拒绝处理...")
+            if config.DEBUG_LEVEL > 0: logger.info(f"检测到违禁词 {w}，拒绝处理...")
             return
 
     # 唤醒词检测
@@ -259,8 +248,7 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
 
     # 其它人格唤醒判断
     if chat.get_chat_preset_key().lower() not in trigger_text.lower() and chat.enable_auto_switch_identity:
-        presets_dict = PersistentDataManager.instance.get_presets(chat_key)
-        for preset_key in presets_dict:
+        for preset_key in chat.preset_keys:
             if preset_key.lower() in trigger_text.lower():
                 chat.change_presettings(preset_key)
                 logger.info(f"检测到 {preset_key} 的唤醒词，切换到 {preset_key} 的人格")
@@ -285,9 +273,9 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
     else:
         if config.CHAT_ENABLE_RECORD_ORTHER:
             await chat.update_chat_history_row(sender=sender_name, msg=trigger_text, require_summary=False)
-            logger.info("不是 bot 相关的信息，记录但不进行回复")
+            if config.DEBUG_LEVEL > 1: logger.info("不是 bot 相关的信息，记录但不进行回复")
         else:
-            logger.info("不是 bot 相关的信息，不进行回复")
+            if config.DEBUG_LEVEL > 1: logger.info("不是 bot 相关的信息，不进行回复")
         return
     
     wake_up = False # 进入对话流程，重置唤醒状态
@@ -296,7 +284,7 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
     await chat.update_chat_history_row_for_user(sender=sender_name, msg=trigger_text, userid=trigger_userid, username=sender_name, require_summary=False)
 
     if chat.get_chat_preset_key() != current_preset_key:
-        logger.warning(f'等待OpenAI请求返回的过程中人格预设由[{current_preset_key}]切换为[{chat.get_chat_preset_key()}],当前消息不再继续响应.1')
+        if config.DEBUG_LEVEL > 0: logger.warning(f'等待OpenAI请求返回的过程中人格预设由[{current_preset_key}]切换为[{chat.get_chat_preset_key()}],当前消息不再继续响应.1')
         return
     
     # 主动聊天参与逻辑 *待定方案
@@ -337,7 +325,7 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
         return
 
     if chat.get_chat_preset_key() != current_preset_key:
-        logger.warning(f'等待OpenAI响应返回的过程中人格预设由[{current_preset_key}]切换为[{chat.get_chat_preset_key()}],当前消息不再继续处理.2')
+        if config.DEBUG_LEVEL > 0: logger.warning(f'等待OpenAI响应返回的过程中人格预设由[{current_preset_key}]切换为[{chat.get_chat_preset_key()}],当前消息不再继续处理.2')
         return
 
     # 用于存储最终回复顺序内容的列表
@@ -473,7 +461,7 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
                     logger.info(f"设置定时器: {reply.get(key)}")
                     loop_data['timer'] = reply.get(key)
                 elif key == 'preset' and reply.get(key):  # 更新对话预设
-                    if PersistentDataManager.instance.update_preset(chat_key=chat.get_chat_key(), preset_key=chat.get_chat_preset_key(), bot_self_introl=reply.get(key)):
+                    if chat.update_preset(preset_key=chat.preset_key, bot_self_introl=reply.get(key))[0]:
                         logger.info(f"更新对话预设: {reply.get(key)} 成功")
                     else:
                         logger.warning(f"更新对话预设: {reply.get(key)} 失败")
@@ -525,4 +513,4 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
                 chat_type=chat_type,
                 is_tome=is_tome,
                 chat_key=chat_key
-            )
\ No newline at end of file
+            )
