@@ -1,4 +1,4 @@
-from nonebot.log import logger
+from .logger import logger
 from nonebot.utils import run_sync
 
 import os
@@ -200,7 +200,7 @@ class TextGenerator(Singleton["TextGenerator"]):
     # 生成对话模板
     @staticmethod
     def generate_msg_template(sender:str, msg: str, time_str: str='') -> str:
-        return f"{time_str}{sender}: {msg}\n"
+        return f"{time_str}{sender}: {msg}"
 
     # 计算字符串的token数量
     @staticmethod
@@ -208,4 +208,4 @@ class TextGenerator(Singleton["TextGenerator"]):
         try:
             return len(tokenizer.encode(msg))
         except:
-            return 2048
\ No newline at end of file
+            return 2048
