@@ -1,4 +1,4 @@
-from nonebot.log import logger
+from .logger import logger
 
 
 TEXT_FUNC_ENABLE = True
@@ -53,4 +53,4 @@ except:
 
 if __name__ == '__main__':
     # 计算两个句子的相似度
-    print(cos_sim('我喜欢吃苹果', '我喜欢吃香蕉'))
\ No newline at end of file
+    print(cos_sim('我喜欢吃苹果', '我喜欢吃香蕉'))
